@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2004, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	$Id: dbutils.c,v 1.23.2.2 2006/10/27 20:09:56 cbbrowne Exp $
+ *	$Id: dbutils.c,v 1.23.2.4 2006-12-06 09:46:09 xfade Exp $
  * ----------------------------------------------------------------------
  */
 
@@ -129,6 +129,16 @@ slon_connectdb(char *conninfo, char *symname)
         slon_log(SLON_DEBUG4,
                 "version for \"%s\" is %d\n", conninfo, conn->pg_version);
 
+	if (conn->pg_version >= 80100)
+        {
+                slon_mkquery(&query, "set escape_string_warning to 'off'");
+                res = PQexec(dbconn, dstring_data(&query));
+                if (!(PQresultStatus(res) == PGRES_COMMAND_OK))
+                {
+                        slon_log(SLON_ERROR, "Unable to set escape_string_warning to off\n");
+                }
+                PQclear(res);
+        }
 	if (conn->pg_version >= 80200)
 	{
 		slon_mkquery(&query, "set standard_conforming_strings to 'off'");
@@ -139,6 +149,7 @@ slon_connectdb(char *conninfo, char *symname)
         	}
 		PQclear(res);
 	}
+	dstring_free(&query);
 	return conn;
 }
 
@@ -521,7 +532,7 @@ static int db_get_version(PGconn *conn)
 	PQclear(res);
 	snprintf(versionstr, 7, "%.2d%.2d%.2d", major, minor, patch);
 	version=atoi(versionstr);
-
+	dstring_free(&query);
 	return version;
 }
 	
